Skip to content

cleanup: save 60 lines/100 bytes by combining two mostly duplicate functions.

Rob Landley linux-nfs 1 version New

Get series with b4
b4 am [email protected]

Versions newest first

  1. v1 Latest1 patch 0 repliesNew

Patches in v1 No applies recorded yet

#Subject and filesSizeRepliesApplied
1/1cleanup: save 60 lines/100 bytes by combining two mostly duplicate functions.fs/nfs/super.c+33 -960 replies

Reviews trailers per patch

No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.

Read the v1 thread